run

Function run 

pub fn run(
    dataflows: &mut [DataflowDescription<Plan, ()>],
    read_policies: &BTreeMap<GlobalId, ReadPolicy>,
    storage_collections: &dyn StorageCollections,
    current_time: Timestamp,
    read_only_mode: bool,
) -> BTreeMap<GlobalId, ReadHold>
Runs as-of selection for the given dataflows.

Assigns the selected as-of to the provided dataflow descriptions and returns a set of ReadHolds that must not be dropped nor downgraded until the dataflows have been installed with the compute controller.