pub(super) type ReplicaResponse = (ReplicaId, u64, ComputeResponse);Expand description
A response from a replica, composed of a replica ID, the replica’s current epoch, and the compute response itself.
pub(super) type ReplicaResponse = (ReplicaId, u64, ComputeResponse);A response from a replica, composed of a replica ID, the replica’s current epoch, and the compute response itself.