forward_messages

Function forward_messages 

async fn forward_messages<C>(
    client: C,
    rx: UnboundedReceiver<ComputeCommand>,
    tx: UnboundedSender<Result<ComputeResponse, Error>>,
)
where C: ComputeClient,
Forward messages between a pair of channels and a ComputeClient.

This functions is run in its own task and exists to allow SequentialHydration::recv to be cancel safe even though it needs to send commands to the wrapped client, which isn’t cancel safe.